/*         Example Translate Phone Module -- North American Format          */
/*      (C) 1995 by Matt Davis - Licensed for use solely with McD-CBV       */

/* McD-CBV supports all telephone formats on the planet via an extremely    * 
 * powerful external translation module system, of which this file is a     * 
 * working example of.  It uses REXX queues to communicate with McD-CBV,    * 
 * and is a normal Adept-REXX program, so all Adept functions are available * 
 * to you for use.                                                          */

ARG Line        /* ARG line is always required                              */               

  AdeptLog(line,3,"  ******************************************")
  AdeptLog(line,3,"  *** In ExternalModule - North American")

/* McD-CBV, before invoking this module, creates a unique queue for that    * 
 * line of the BBS.  On line 1, McD-CBV creates a queue called McD_Command1.* 
 * Before passing to the external module, McD-CBV puts the command in this  * 
 * queue which tells the module what function it is supposed to carry-out.  */

/*RXQUEUE('Get','McD_Command'line)*/
RXQUEUE('Set','McD_Command'line)


/* Pull the command in McD_Command%line% and set to the variable 'Action'   */

PULL Action

/* McD-CBV also creates another unique queue (McD_CBV%line%) in which it    */
/* puts the data which the module will need to work with.                   */

/*RXQUEUE('Get','McD_CBV'line)*/
RXQUEUE('Set','McD_CBV'line)


/* This branch takes McD-CBV to alternate functions depending on the action */
/* put in the queue by McD-CBV telling the module what command to carry-out.*/
/*                                                                          */
/* FIX.......DeBotch the phone number in the queue                          */
/* TRANS.....Translate the phone number in the queue                        */
/* ENTER.....Prompt the user to enter a phone number                        */  

SELECT
  WHEN Action = 'FIX'   THEN CALL FixPhones
  WHEN Action = 'TRANS' THEN CALL TranslatePhones
  WHEN Action = 'ENTER' THEN CALL EnterPhone
  OTHERWISE CALL Error
END

/****************************************************************************/
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/****************************************************************************/

FixPhones:

  AdeptLog(line,3,"  *** Fixing phone number")

IF Translating <> 'YES' THEN PULL NumToInterpret

    OverLayPointer = LASTPOS('(',NumToInterpret)
    DO WHILE OverlayPointer > '0'
      NumToInterpret   = OVERLAY(' ',NumToInterpret,OverLayPointer)
      NumToInterpret   = SPACE(NumToInterpret,0)
      OverLayPointer = LASTPOS('(',NumToInterpret)
    END

    OverLayPointer = LASTPOS(')',NumToInterpret)
    DO WHILE OverlayPointer > '0'
      NumToInterpret   = OVERLAY(' ',NumToInterpret,OverLayPointer)
      NumToInterpret   = SPACE(NumToInterpret,0)
      OverLayPointer = LASTPOS(')',NumToInterpret)
    END

    OverLayPointer = LASTPOS('[',NumToInterpret)
    DO WHILE OverlayPointer > '0'
      NumToInterpret   = OVERLAY(' ',NumToInterpret,OverLayPointer)
      NumToInterpret   = SPACE(NumToInterpret,0)
      OverLayPointer = LASTPOS('[',NumToInterpret)
    END

    OverLayPointer = LASTPOS(']',NumToInterpret)
    DO WHILE OverlayPointer > '0'
      NumToInterpret   = OVERLAY(' ',NumToInterpret,OverLayPointer)
      NumToInterpret   = SPACE(NumToInterpret,0)
      OverLayPointer = LASTPOS(']',NumToInterpret)
    END

    OverLayPointer = LASTPOS('-',NumToInterpret)
    DO WHILE OverlayPointer > '0'
      NumToInterpret   = OVERLAY(' ',NumToInterpret,OverLayPointer)
      NumToInterpret   = SPACE(NumToInterpret,0)
      OverLayPointer = LASTPOS('-',NumToInterpret)
    END

    IF LENGTH(NumToInterpret) = '7' THEN NumToInterpret = DefaultAreaCode''NumToInterpret
             NumToInterpret   = RIGHT(NumToInterpret,10,0)
             AreaCode         = LEFT(NumToInterpret,3)
             NumToInterpret   = RIGHT(NumToInterpret,7)
             FirstThree       = LEFT(NumToInterpret,3)
             LastFour         = RIGHT(NumToInterpret,4)
  
    NumToInterpret = AreaCode"-"FirstThree"-"LastFour

IF Translating <> 'YES' THEN PUSH NumToInterpret

IF Translating = 'YES' THEN RETURN
                       ELSE SIGNAL Exit

/****************************************************************************/
/****************************************************************************/

TranslatePhones:

PULL NumToTranslate

AdeptLog(line,3,"  *** Started with: "NumToTranslate)

Translating = 'YES'

NumToInterpret = NumToTranslate

CALL FixPhones

NumToTranslate = NumToInterpret

Translating = ''

PARSE VALUE NumToTranslate WITH Areacode'-'Prefix'-'Caboose
McD_Translate = 'McD-CBV.90\Data\CBV-Translate'

NumToTranslate = Areacode'-'Prefix

  STREAM(McD_Translate,'c','OPEN READ')
  STREAM(McD_Translate,'c','seek 1')

DO WHILE Lines(McD_Translate) > '0'
   PARSE VALUE LineIn(McD_Translate) WITH Influx
   PARSE VALUE Influx WITH Type '=' Data
   PARSE UPPER VAR Type Type
   Data = STRIP(Data)
   Type = STRIP(Type)

     IF Type = 'LOCALTRANS' THEN LocalTrans = Data
                            ELSE LocalTrans = '000'

  IF NumToTranslate = LocalTrans THEN DO
    Type            = 'Local'
    CallType        = 'Local'
    TranslatedPhone = Prefix'-'Caboose
    NumberToCall    = Prefix'-'Caboose
    CALL AdeptLog line,3,"  *** Translated to: "TranslatedPhone" ("CallType")"
    STREAM(McD_Translate,'c','CLOSE')
    CALL PushTranslated
  END
END

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

STREAM(McD_Translate,'c','seek 1')

DO WHILE Lines(McD_Translate) > '0'
   PARSE VALUE LineIn(McD_Translate) WITH Influx
   PARSE VALUE Influx WITH Type '=' Data
   PARSE UPPER VAR Type Type
   Data = STRIP(Data)

     IF Type = 'LONGTRANS' THEN LongTrans = Data
                           ELSE LongTrans = '000'

  IF NumToTranslate = LongTrans THEN DO
    Type            = 'Long'
    CallType        = 'Long Distance'
    LDType          = 'Short'
    TranslatedPhone = Prefix'-'Caboose
    NumberToCall    = Prefix'-'Caboose
    CALL AdeptLog line,3,"  *** Translated to: "TranslatedPhone" ("CallType"1)"
    STREAM(McD_Translate,'c','CLOSE')
    CALL PushTranslated
  END
END

/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */

Type            = 'Long'
CallType        = 'Long Distance'
LDType          = 'Long'
TranslatedPhone = '1-'AreaCode'-'PreFix'-'Caboose
NumberToCall    = '1-'AreaCode'-'Prefix'-'Caboose
CALL AdeptLog line,3,"  *** Translated to: "TranslatedPhone" ("CallType"2)"
STREAM(McD_Translate,'c','CLOSE')

/****************************************************************************/

PushTranslated:

  PUSH TranslatedPhone'/'NumberToCall'/'Type'/'CallType'/'LDType

  SIGNAL Exit

/****************************************************************************/
/****************************************************************************/

EnterPhone:

  AdeptLog(line,3,"  *** Entering Phone Number")
  AdeptPrint(line,"\r{CL                                   {F9[{F8###{F9-{F8###{F9-{F8####{F9]\r\n")
  AdeptPrint(line,"{F3Please enter the new phone number{F2: [            ]\r[36C{FF")
  NewPhone = AdeptInput(Line,10,12,,,,,,)

  Push NewPhone

  SIGNAL Exit

/****************************************************************************/
/****************************************************************************/

Error:

  SIGNAL Exit

/****************************************************************************/
/* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
/****************************************************************************/

Exit:

  AdeptLog(line,3,"  ******************************************")
  EXIT

/****************************************************************************/
